Option Explicit

Const BIF_RETURNONLYFSDIRS = 1

QuickInstall

' Builds the path for the destination folder with the option to archive any existing data.
Function BuildPath(FileSystemObject, DestinationFolder)
    Dim Msg

    ' Check to see if the current destination folder exists.
    If FileSystemObject.FolderExists(DestinationFolder) Then
        ' If it exists, provide the option to replace.
        Msg = "The install folder already exists." & vbCrLf & "Replace this installation?"

        ' Get the operator selection.
        Select Case MsgBox(Msg, vbQuestion Or vbYesNo, "Quick Install")
        Case vbYes
            ' Create the parent folder for the new archive folder.
            CreateFolder FileSystemObject, FileSystemObject.GetParentFolderName(DestinationFolder)

            ' Create archive folder to move the original destination folder to.
            FileSystemObject.MoveFolder DestinationFolder, FileSystemObject.BuildPath(FileSystemObject.GetParentFolderName(DestinationFolder), FileSystemObject.GetTempName)

            ' Return Success
            BuildPath = True
        Case vbNo
            ' Return failure if the user selects No.
            BuildPath = False
        End Select
    Else
        ' The destination folder does not exist, create its parent folder.
        CreateFolder FileSystemObject, FileSystemObject.GetParentFolderName(DestinationFolder)
        BuildPath = True
    End If
End Function

Sub ClickExecute(strCommand, strPath)
    Dim oShell, CurrentDirectory

    Set oShell = CreateObject("WScript.Shell")
    'MsgBox strPath
    CurrentDirectory = oShell.CurrentDirectory
    oShell.CurrentDirectory = strPath
    'MsgBox oShell.CurrentDirectory
    'MsgBox strCommand
    oShell.Run strCommand

    oShell.CurrentDirectory = CurrentDirectory
End Sub

' Attempts to systematically create the folder specified.
Sub CreateFolder(FileSystemObject, FolderSpec)
    Dim ParentFolder

    ' Get the parent folder for the folder specified.
    ParentFolder = FileSystemObject.GetParentFolderName(FolderSpec)

    ' If the parent folder does not exist, attempt to systematically create it.
    If Not FileSystemObject.FolderExists(ParentFolder) Then CreateFolder FileSystemObject, ParentFolder

    ' If the current folder does not exist, create it.
    If Not FileSystemObject.FolderExists(FolderSpec) Then FileSystemObject.CreateFolder FolderSpec
End Sub

Sub QuickInstall
    Dim FileSystemObject, CurrentFolder, WshShell, LinkFile, DesktopFolder, ShellLink, AppShell, DestinationFolder

    ' Get the shell and file system object instances.
    Set AppShell = CreateObject("Shell.Application")
    Set WshShell = CreateObject("WScript.Shell")
    Set FileSystemObject = CreateObject("Scripting.FileSystemObject")

    ' Get the current folder for the CD and the desktop folder.
    CurrentFolder = WshShell.CurrentDirectory
    DesktopFolder = WshShell.SpecialFolders("Desktop")

    ' Determine whether of not the operator wishes to install to the default path.
    Select Case MsgBox("Do you wish to install NUSS to the C:\WPSI\NUSS folder?", vbQuestion Or vbYesNoCancel, "Quick Install")
    Case vbCancel
        ' If cancelling, exit.
        Exit Sub
    Case vbYes
        ' If yes, set the default path.
        DestinationFolder = "C:\WPSI\NUSS"
    Case vbNo
        ' Get the destination file for the NUSS software.
        Set DestinationFolder = AppShell.BrowseForFolder(0, "Select Folder for NUSS application", BIF_RETURNONLYFSDIRS)
        If DestinationFolder Is Nothing Then Exit Sub
        If IsObject(DestinationFolder) Then DestinationFolder = DestinationFolder.Self.Path
    End Select

    If BuildPath(FileSystemObject, DestinationFolder) Then
        ' Copy the NUSS folder to the C drive.
        FileSystemObject.CopyFolder FileSystemObject.BuildPath(CurrentFolder, "NUSS"), DestinationFolder, True

        ' Get the link file for the NUSS application.
        LinkFile = FileSystemObject.BuildPath(DesktopFolder, "NetScanner(tm) Unified Startup Software.lnk")
        If FileSystemObject.FileExists(LinkFile) Then FileSystemObject.DeleteFile LinkFile

        ' Create and initialize the link on the desktop.
        Set ShellLink = WshShell.CreateShortcut(LinkFile)
        ShellLink.TargetPath = FileSystemObject.BuildPath(DestinationFolder, "NUSS.EXE")
        ShellLink.WorkingDirectory = DestinationFolder
        ShellLink.IconLocation = FileSystemObject.BuildPath(DestinationFolder, "NUSS.EXE")
        ShellLink.Save

        ' Indicate to the operator the installation was successful.
        MsgBox "Quick Install Successful"
    End If
End Sub
